FastListViewLayoutDelegate<T extends FastItem> class abstract

An abstract class that defines a delegate object for the FastListViewLayout widget.

The purpose of this delegate object is to provide a way to customize the appearance and behavior of the FastListViewLayout widget. Subclasses of FastListViewLayoutDelegate must implement the willBuildListViewForCategory method to provide the view for each category of items.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
willBuildListViewForCategory(FastListViewLayout<FastItem> listViewLayout, FastListItemCategory<T> category) → Widget?
Builds the list view for the given category of items

Operators

operator ==(Object other) → bool
The equality operator.
inherited