FastCategory class

Inheritance
Implementers

Constructors

FastCategory({required String labelText, required String valueText, double weight = 0.0})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
labelText → String
Text that describes a category label.
final
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
valueText → String
Text that describes a category value.
final
weight → double
Represents the weight of a category. min: 0 max: 9999
final

Methods

assignValue<T>(T? value, {T? defaultValue, bool loose = true}) → T?
inherited
clone() → FastCategory
Creates a copy of this TModel.
override
copyWith({String? labelText, String? valueText, double? weight}) → FastCategory
Creates a copy of this TModel but with the given fields replaced with the new values.
override
copyWithDefaults() → TModel
inherited
merge(covariant FastCategory model) → FastCategory
Creates a new TModel where each properties from this object has been merged with the matching properties from the other object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited