FastJob class abstract

Constructors

FastJob({Duration timeLimit = const Duration(seconds: 15), bool requestUserInteraction = false, String? debugLabel})
const

Properties

debugLabel → String?
final
hashCode → int
The hash code for this object.
no setterinherited
requestUserInteraction → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeLimit → Duration
final

Methods

initialize(BuildContext context, {IFastErrorReporter? errorReporter}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(BuildContext context, {IFastErrorReporter? errorReporter}) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited