FastPopupMenuButton<T> class

Inheritance

Constructors

FastPopupMenuButton({Key? key, required PopupMenuItemBuilder<T> itemBuilder, required Widget icon, T? initialValue, VoidCallback? onOpened, PopupMenuItemSelected<T>? onSelected, PopupMenuCanceled? onCanceled, String? tooltip, double? elevation, Color? shadowColor, Offset offset = Offset.zero, bool enabled = true, ShapeBorder? shape, Color? color, BoxConstraints? constraints, PopupMenuPosition? position, Widget? child, Clip clipBehavior = Clip.none, EdgeInsetsGeometry? padding, double? iconSize, Alignment? iconAlignment})
const

Properties

child → Widget?
If provided, child is the widget used for this button and the button will utilize an InkWell for taps.
final
clipBehavior → Clip
The content will be clipped (or not) according to this option.
final
color → Color?
If provided, the background color used for the menu.
final
constraints → BoxConstraints?
Optional size constraints for the menu.
final
elevation → double?
The z-coordinate at which to place the menu when open. This controls the size of the shadow below the menu.
final
enabled → bool
Whether this popup menu button is interactive.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
If provided, the icon is used for this button and the button will behave like an IconButton.
final
iconAlignment → Alignment
final
iconSize → double
If provided, the size of the Icon.
final
initialValue → T?
The value of the menu item, if any, that should be highlighted when the menu opens.
final
itemBuilder → PopupMenuItemBuilder<T>
Called when the button is pressed to create the items to show in the menu.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset → Offset
The offset is applied relative to the initial position set by the position.
final
onCanceled → PopupMenuCanceled?
Called when the user dismisses the popup menu without selecting an item.
final
onOpened → PopupMenuCanceled?
Called when the popup menu is shown.
final
onSelected → PopupMenuItemSelected<T>?
Called when the user selects a value from the popup menu created by this button.
final
padding → EdgeInsetsGeometry
Matches IconButton's 8 dps padding by default. In some cases, notably where this button appears as the trailing element of a list item, it's useful to be able to set the padding to zero.
final
position → PopupMenuPosition?
Whether the popup menu is positioned over or under the popup menu button.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
The color used to paint the shadow below the menu.
final
shape → ShapeBorder?
If provided, the shape used for the menu.
final
tooltip → String?
Text that describes the action that will occur when the button is pressed.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FastPopupMenuButton<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited