FastSelectField<T> class

Inheritance

Constructors

FastSelectField({Key? key, required ValueChanged<FastItem<T>?> onSelectionChanged, required String labelText, required List<FastItem<T>> items, String searchPlaceholderText = kFastSearchPlaceholderText, String clearSelectionText = kFastClearSelectionText, Widget clearSearchIcon = kFastClearSearchIcon, String searchTitleText = kFastSelectTitleText, bool showHelperBoundaries = true, Widget closeIcon = kFastCloseIcon, Widget backIcon = kFastBackIcon, bool canClearSelection = true, int intialCategoryIndex = 0, bool groupByCategory = false, bool useFuzzySearch = false, bool isReadOnly = false, bool sortItems = true, bool isEnabled = true, String? placeholderText, String? allCategoryText, List<FastListItemCategory<FastItem<T>>> extraTabBuilder()?, String? captionText, String? helperText, List<FastCategory>? categories, FastListViewLayoutDelegate<FastItem<T>>? searchPageDelegate, FastItem<T>? selection, Widget? listViewEmptyContent, String? listViewEmptyText, VoidCallback? onSearchPageClose, FastFastSelectFieldDelegate<FastItem<T>>? delegate})
const

Properties

allCategoryText → String?
final
backIcon → Widget
final
canClearSelection → bool
final
captionText → String?
final
categories → List<FastCategory>?
final
clearSearchIcon → Widget
final
clearSelectionText → String
final
closeIcon → Widget
final
delegate → FastFastSelectFieldDelegate<FastItem<T>>?
final
extraTabBuilder → List<FastListItemCategory<FastItem<T>>> Function()?
A function that creates additional tab views.
final
groupByCategory → bool
final
hashCode → int
The hash code for this object.
no setterinherited
helperText → String?
final
intialCategoryIndex → int
final
isEnabled → bool
final
isReadOnly → bool
final
items → List<FastItem<T>>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText → String
final
listViewEmptyContent → Widget?
final
listViewEmptyText → String?
final
onSearchPageClose → VoidCallback?
final
onSelectionChanged → ValueChanged<FastItem<T>?>
final
placeholderText → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchPageDelegate → FastListViewLayoutDelegate<FastItem<T>>?
The delegate object that can modify the behavior of the widget.
final
searchPlaceholderText → String
final
searchTitleText → String
final
selection → FastItem<T>?
final
showHelperBoundaries → bool
final
sortItems → bool
final
useFuzzySearch → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited