FastLinearProgressBarIndicator class

A linear progress bar indicator.

Inheritance

Constructors

FastLinearProgressBarIndicator({Key? key, Duration animationDuration = const Duration(milliseconds: 300), bool showProgressLabel = false, bool showAsPercentage = false, int fractionDigits = 2, double minBarHeight = 8, double maxValue = 100, bool animate = true, double barRadius = 4, double minValue = 0, double value = 0, StringCallback<double>? progressLabelBuilder, Color? progressLabelColor, Color? backgroundColor, VoidCallback? onAnimationEnd, Color? barColor, FastPaletteScheme? palette})
const

Properties

animate → bool
Whether to animate the progress bar.
final
animationDuration → Duration
The duration of the animation.
final
backgroundColor → Color?
The background color of the progress bar.
final
barColor → Color?
The color of the progress bar.
final
barRadius → double
The radius of the progress bar.
final
fractionDigits → int
The number of digits after the decimal point.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue → double
The maximum value of the progress bar.
final
minBarHeight → double
The minimum height of the progress bar.
final
minValue → double
The minimum value of the progress bar.
final
onAnimationEnd → VoidCallback?
A callback that is called when the animation ends.
final
palette → FastPaletteScheme?
The palette to use for the progress bar.
final
progressLabelBuilder → StringCallback<double>?
A callback that takes a double value and returns a String.
final
progressLabelColor → Color?
The color of the progress label.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAsPercentage → bool
Whether to show the progress as a percentage.
final
showProgressLabel → bool
Whether to show the progress label.
final
value → double
The current value of the progress bar.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FastLinearProgressBarIndicator>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited