FastSelectableListItem<T extends FastItem> class

Inheritance

Constructors

FastSelectableListItem({Key? key, required VoidCallback onTap, bool capitalizeLabelText = true, bool isSelected = false, bool isEnabled = true, bool isDense = true, Color? selectionTralingColor, Color? selectionLabelColor, String? descriptionText, EdgeInsets? contentPadding, Color? selectionColor, String? labelText, Widget? trailing, Widget? leading, T? item})

Properties

capitalizeLabelText → bool
final
contentPadding → EdgeInsets?
final
descriptionText → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isDense → bool
final
isEnabled → bool
final
isSelected → bool
final
item → T?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText → String?
final
leading → Widget?
final
onTap → VoidCallback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionColor → Color?
final
selectionLabelColor → Color?
final
selectionTralingColor → Color?
Allow to convert the label to beginning of sentence case.
final
trailing → Widget?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited