FastSelectableListView<T extends FastItem> class

Inheritance

Constructors

FastSelectableListView({Key? key, required ValueChanged<T> onSelectionChanged, required List<T> items, String searchPlaceholderText = kFastSearchPlaceholderText, Widget clearSearchIcon = kFastClearSearchIcon, bool shouldUseFuzzySearch = false, bool showSearchBar = false, EdgeInsets padding = EdgeInsets.zero, bool groupByCategory = false, bool isViewScrollable = true, bool showItemDivider = false, int intialCategoryIndex = 0, bool sortItems = true, bool isEnabled = true, Color? selectionTralingColor, Color? selectionLabelColor, EdgeInsets? itemContentPadding, String? allCategoryText, List<FastListItemCategory<T>> extraTabBuilder()?, FastListItemBuilder<T>? listItemBuilder, Color? selectionColor, List<FastCategory>? categories, T? selection, FastListViewLayoutDelegate<T>? delegate, Widget? listViewEmptyContent, String? listViewEmptyText})
const

Properties

allCategoryText → String?
final
categories → List<FastCategory>?
final
clearSearchIcon → Widget
final
delegate → FastListViewLayoutDelegate<T>?
The delegate object that can modify the behavior of the widget.
final
extraTabBuilder → List<FastListItemCategory<T>> Function()?
A function that creates additional tab views.
final
groupByCategory → bool
final
hashCode → int
The hash code for this object.
no setterinherited
intialCategoryIndex → int
final
isEnabled → bool
final
isViewScrollable → bool
final
itemContentPadding → EdgeInsets?
final
items → List<T>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listItemBuilder → FastListItemBuilder<T>?
final
listViewEmptyContent → Widget?
final
listViewEmptyText → String?
final
onSelectionChanged → ValueChanged<T>
final
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchPlaceholderText → String
final
selection → T?
final
selectionColor → Color?
final
selectionLabelColor → Color?
final
selectionTralingColor → Color?
final
shouldUseFuzzySearch → bool
final
showItemDivider → bool
final
showSearchBar → bool
final
sortItems → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited